@@ -10,13 +10,20 @@ __all__ = [
             'API', 'Store', 'Magento',
             'Customer', 'CustomerGroup', 'CustomerAddress',
             'Country', 'Region',
+            'Cart', 'CartCoupon', 'CartCustomer',
+            'CartPayment', 'CartProduct', 'CartShipping',
+            
             'Category', 'CategoryAttribute', 'Product', 'ProductAttribute',
             'ProductAttributeSet', 'ProductTypes', 'ProductImages',
             'ProductTierPrice', 'ProductLinks', 'ProductConfigurable',
-            'Inventory', 'Order', 'Shipment', 'Invoice', '__version__'
+            'Inventory', 'Order', 'Shipment', 'Invoice', '__version__',
+            'Client',
             ]
 
 from .api import API
+from .client import Client
+from .checkout import Cart, CartCoupon, CartCustomer
+from .checkout import CartPayment, CartProduct, CartShipping
 from .miscellaneous import Store, Magento
 from .customer import Customer, CustomerGroup, CustomerAddress
 from .directory import Country, Region
