@@ -31,17 +31,9 @@ class API(object):
     """
     Generic API to connect to magento
     """
-    __slots__ = (
-        'url',
-        'username',
-        'password',
-        'session',
-        'client',
-        'protocol',
-    )
 
     def __init__(self, url, username, password,
-                 version='1.3.2.4', full_url=False, protocol='xmlrpc'):
+                 version='1.3.2.4', full_url=False, protocol='xmlrpc', transport=None):
         """
         This is the Base API class which other APIs have to subclass. By
         default the inherited classes also get the properties of this
@@ -53,8 +45,6 @@ class API(object):
 
             class Core(API):
 
-                __slots__ = ( )
-
                 def websites(self):
                     return self.call('ol_websites.list', [])
 
@@ -106,6 +96,8 @@ class API(object):
         :param full_url: If set to true, then the `url` is expected to
                     be a complete URL
         :param protocol: 'xmlrpc' and 'soap' are valid values
+        :param transport: optional xmlrpclib.Transport subclass for
+                    use in xmlrpc requests
         """
         assert protocol \
             in PROTOCOLS, "protocol must be %s" % ' OR '.join(PROTOCOLS)
@@ -113,6 +105,8 @@ class API(object):
         self.username = username
         self.password = password
         self.protocol = protocol
+        self.version = version
+        self.transport = transport
         self.session = None
         self.client = None
 
@@ -122,7 +116,11 @@ class API(object):
         but does not login. This could be used as a connection test
         """
         if self.protocol == 'xmlrpc':
-            self.client = ServerProxy(self.url, allow_none=True)
+            if self.transport:
+                self.client = ServerProxy(
+                    self.url, allow_none=True, transport=self.transport)
+            else:
+                self.client = ServerProxy(self.url, allow_none=True)
         else:
             self.client = Client(self.url)
 
@@ -171,3 +169,4 @@ class API(object):
             return self.client.multiCall(self.session, calls)
         else:
             return self.client.service.multiCall(self.session, calls)
+
